/*
 * $Id: main.c 1 2007-01-24 13:23:49Z jos $
 *
 * libspi example code (tries to detect DSerial)
 *
 * by Jos Hendriks <jos@circuitdb.com>
 */
#include <nds.h>
#include <nds/arm9/console.h> //basic print funcionality
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <spi.h>

void detectDSe() {
	int retval;
	uint8_t read_byte;
	
  char send_byte = 0x9f;
  
  retval = writeBlocking_cardSPI(send_byte);
  if (retval==CARD_SPI_OK)
  {
  	writeBlocking_cardSPI(0x00);
  	writeBlocking_cardSPI(0x00);
  }else{
    iprintf("Error detecting DSerial\n");
    return;
  }
      
  writeBlocking_cardSPI(0x00);
  retval = readBlocking_cardSPI(&read_byte);
  if (retval==CARD_SPI_OK)
  { 
    if (read_byte==0xab){
    	iprintf("DSerial detected\n");
    }else{
      iprintf("Error detecting DSerial\n");
      return;
    }
  }else{
    iprintf("Error detecting DSerial\n");
    return;
  }
}

int main(void) {
  videoSetMode(0);  //not using the main screen
  videoSetModeSub(MODE_0_2D | DISPLAY_BG0_ACTIVE);  //sub bg 0 will be used to print text
  vramSetBankC(VRAM_C_SUB_BG);

  SUB_BG0_CR = BG_MAP_BASE(31);

  BG_PALETTE_SUB[255] = RGB15(31,31,31);  //by default font will be rendered with color 255

  //consoleInit() is a lot more flexible but this gets you up and running quick
  consoleInitDefault((u16*)SCREEN_BASE_BLOCK_SUB(31), (u16*)CHAR_BASE_BLOCK_SUB(0), 16);

#ifdef ARM9
	WAIT_CR &= ~ARM9_OWNS_CARD; /* NDS Slot Access Rights(0=ARM9, 1=ARM7) */
#else
	WAIT_CR |= ARM9_OWNS_CARD;
#endif

  /* initialise the SPI driver */
  iprintf("Init SPI driver\n");
  init_cardSPI();

  /* config the driver, no interrupt requests */
  config_cardSPI( CARD_SPI_1_MHZ_CLOCK, 0);

  detectDSe();

  iprintf("Press A to detect DSerial again\n");

  scanKeys();
  while(1) {
    uint32 pressed;
    
    scanKeys();
    pressed = keysDown();

    if ( pressed & KEY_A) {
      detectDSe();
    }
  }    
  return 0;
}
